<template>
    <div class="system-add-menu-container">
        <el-dialog :title="title" v-model="isShowRFIDDialog" width="600px">
            <el-form :model="RFIDForm" :rules="RFIDFormRules" ref="RFIDFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="RFID名称" prop="rfidName">
                            <el-input class="input-add" v-model.trim="RFIDForm.rfidName" placeholder="请输入RFID名称" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="RFID编码" prop="rfid">
                            <el-input class="input-add" v-model.trim="RFIDForm.rfid" placeholder="请输入RFID编码" clearable></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="isShowRFIDDialog = !isShowRFIDDialog" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitRFID" v-throttle size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script lang="ts">
interface stateType {
    isShowRFIDDialog: Boolean;
    RFIDForm: {
        rfid: string;
        rfidName: string;
    };
    title: string;
    RFIDFormRules: {};
}
interface levelListState {}
import { reactive, toRefs, ref } from 'vue';
import { RFIDApi } from '/@/api/intellectInspectSystem/RFID';
import { ElMessage } from 'element-plus';
export default {
    name: 'RFIDDialog',
    setup(props: any, context: any) {
        const RFIDFormRef = ref();
        const state = reactive<stateType>({
            title: '',
            isShowRFIDDialog: false,
            RFIDForm: {
                rfid: '',
                rfidName: ''
            },
            RFIDFormRules: {
                rfid: [{ required: true, message: '请填写RFID编码', trigger: 'blur' }],
                rfidName: [{ required: true, message: '请填写RFID名称', trigger: 'change' }],
                riskLevel: [{ required: true, message: '请选择风险等级', trigger: 'change' }],
                location: [{ required: true, message: '请填写区域位置', trigger: 'blur' }]
            }
        });

        //打开模态框
        const openRFIDDialog = (type: string, value: object) => {
            state.isShowRFIDDialog = true;
            setTimeout(() => {
                RFIDFormRef.value.clearValidate();
            });
            if (type === '新增') {
                state.title = '新增RFID';
                state.RFIDForm = {
                    rfid: '',
                    rfidName: ''
                };
            } else {
                state.title = '修改RFID';
                state.RFIDForm = JSON.parse(JSON.stringify(value));
            }
        };

        //新增修改提交
        const submitRFID = async () => {
            RFIDFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    if (state.title === '新增巡检指标') {
                        let res = await RFIDApi().addRFID(state.RFIDForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检指标新增成功',
                                duration: 2000
                            });
                            state.isShowRFIDDialog = false;
                            context.emit('refreshRFID');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        let res = await RFIDApi().modRFID(state.RFIDForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检指标修改成功',
                                duration: 2000
                            });
                            state.isShowRFIDDialog = false;
                            context.emit('refreshRFID');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        return {
            ...toRefs(state),
            RFIDFormRef,
            submitRFID,
            openRFIDDialog
        };
    }
};
</script>

<style scoped></style>
